Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2288)

Unified Diff: net/spdy/spdy_session.h

Issue 8319015: Don't send preface-PING. Send trailing ping 200ms (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/spdy/spdy_session.cc » ('j') | net/spdy/spdy_session.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/spdy/spdy_session.h
===================================================================
--- net/spdy/spdy_session.h (revision 105866)
+++ net/spdy/spdy_session.h (working copy)
@@ -525,10 +525,10 @@
// status.
bool check_ping_status_pending_;
- // Indicate if the last data we sent was a ping (generally, a trailing ping).
- // This helps us to decide if we need yet another trailing ping, or if it
- // would be a waste of effort (and MUST not be done).
- bool last_sent_was_ping_;
+ // Indicate if we need to send a ping (generally, a trailing ping). This helps
+ // us to decide if we need yet another trailing ping, or if it would be a
+ // waste of effort (and MUST not be done).
+ bool need_to_send_ping_;
jar (doing other things) 2011/10/17 22:09:28 Nice improvement on comments!
ramant (doing other things) 2011/10/17 23:40:57 Done.
// Initial send window size for the session; can be changed by an
// arriving SETTINGS frame; newly created streams use this value for the
« no previous file with comments | « no previous file | net/spdy/spdy_session.cc » ('j') | net/spdy/spdy_session.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698